@@ -8,8 +8,10 @@ which is divided into 4 steps
 4. present the result
 '''
 
+from asyncio import constants
 from calendar import c
 from msilib.schema import Error
+from sqlite3 import paramstyle
 from turtle import shape
 from unicodedata import decimal
 from unittest import expectedFailure
@@ -196,6 +198,7 @@ class Univariate(ptf_analysis):
         average of the groups at each time point
         '''
         import numpy as np
+
         # get the sample groups by time 得到按时间分组的样本
         groups_time = self.divide_by_time(self.sample)
         # generate table of  average return for group and time 生成组和时间的表格
@@ -251,10 +254,24 @@ class Univariate(ptf_analysis):
         '''
         import numpy as np
         from scipy import stats
+        from .adjust import newey_west_t
         
         self.result = self.difference(self.average_by_time())
+        r, c = np.shape(self.result)
         self.average = np.nanmean(self.result, axis=1)
-        self.ttest = stats.ttest_1samp(self.result, 0.0, axis=1, nan_policy='omit')
+        if self.maxlag == 0 :
+            self.ttest = stats.ttest_1samp(self.result, 0.0, axis=1, nan_policy='omit')
+        else:
+            self.ttest = np.zeros((2, r))
+
+            for i in range(r):
+                temp_result = self.result[i, :]
+                temp_result = temp_result[~np.isnan(temp_result)]
+                temp_one = np.ones((len(temp_result), 1))
+                tvalue, pvalue = newey_west_t(y=temp_result, X=temp_one, J=self.maxlag, constant=False)
+                self.ttest[0, i] = tvalue
+                self.ttest[1, i] = pvalue
+
         # if there is a facotr adjustment, then normal return result plus the anomaly result
 #        if self.factor is not None  :
 #            self.alpha, self.alpha_tvalue = self.factor_adjustment(self.result)
@@ -700,6 +717,7 @@ class Univariate(ptf_analysis):
         '''
         import numpy as np
         from prettytable import PrettyTable
+
         # generate Table if no factor
         table = PrettyTable()
         table.add_column('Group', ['Average', 'T-Test'])
@@ -827,6 +845,7 @@ class Bivariate(ptf_analysis):
         average of the groups at each time point
         '''
         import numpy as np
+
         # get the sample groups by time 得到按时间分组的样本
         groups_time = self.divide_by_time()
         # generate table of  average return for group and time 生成组和时间的表格
@@ -967,16 +986,44 @@ class Bivariate(ptf_analysis):
         '''
         import numpy as np
         from scipy import stats
+        from .adjust import newey_west_t
         
         self.result = self.difference(self.average_by_time(**kwargs))
+        r, c, z = np.shape(self.result)
         self.average = np.nanmean(self.result, axis=2)
-        self.ttest = stats.ttest_1samp(self.result, 0.0, axis=2, nan_policy='omit')
+        
+        if self.maxlag == 0 :
+            self.ttest = stats.ttest_1samp(self.result, 0.0, axis=2, nan_policy='omit')
+        else:
+            self.ttest = np.zeros((2, r, c))
+
+            for i in range(r):
+                for j in range(c):
+                    temp_result = self.result[i, j, :]
+                    temp_result = temp_result[~np.isnan(temp_result)]
+                    temp_one = np.ones((len(temp_result), 1))
+                    tvalue, pvalue = newey_west_t(y=temp_result, X=temp_one, J=self.maxlag, constant=False)
+                    self.ttest[0, i, j] = tvalue
+                    self.ttest[1, i, j] = pvalue
+#        if self.maxlag == 0 :
+#            self.ttest = stats.ttest_1samp(self.result, 0.0, axis=1, nan_policy='omit')
+#        else:
+#            self.ttest = np.zeros((2, r))
+
+#            for i in range(r):
+#                temp_result = self.result[i, :]
+#                temp_result = temp_result[~np.isnan(temp_result)]
+#                temp_one = np.ones((len(temp_result), 1))
+#                tvalue, pvalue = newey_west_t(y=temp_result, X=temp_one, J=self.maxlag, constant=False)
+#                self.ttest[0, i] = tvalue
+#                self.ttest[1, i] = pvalue
+
         # if there is a facotr adjustment, then normal return result plus the anomaly result
 #        if self.factor is not None  :
 #            self.alpha, self.alpha_tvalue = self.factor_adjustment(self.result)
 #            return self.average, self.ttest, self.alpha, self.alpha_tvalue
 
-        return self.average,self.ttest
+        return self.average, self.ttest
 
     def fit(self, **kwargs):
         self.summary_and_test(**kwargs)
@@ -1025,6 +1072,7 @@ class Bivariate(ptf_analysis):
         '''
         import numpy as np
         from prettytable import PrettyTable
+        
         # generate Table if no factor
         if self._factor is None :
             table=PrettyTable()
@@ -1457,36 +1505,3 @@ class Spanning_test():
         
         table.float_format = '.5'
         print(table)
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-        
-        
-
-        
-        
-        
-        
-
-
-        
-        
