@@ -329,4 +329,103 @@ print('t1 and t4:', np.corrcoef(c_t1, c_t4))
 print('inv t1 and inv t3', np.corrcoef(1/c_t1, 1/c_t3))
 
 
+# %%
+import numpy as np
+from portfolio_analysis import Univariate as uni
+    
+    # generate time 
+year=np.ones((3000,1),dtype=int)*2020
+for i in range(19):
+    year=np.append(year,(2019-i)*np.ones((3000,1),dtype=int))
+    
+    # generate variables
+variable_1 = np.random.normal(0, 1, 20*3000)
+variable_2 = np.random.normal(0, 1, 20*3000)
+    # generate character
+character=np.random.normal(0,1,20*3000)
+    # generate future return
+ret=character*-0.5+np.random.normal(0,1,20*3000)
+    # create sample containing future return, character, time
+sample=np.array([ret,character,year]).T
+    # generate the Univiriate Class
+
+# %%
+exper=uni(sample,9)
+exper.fit()
+exper.print_summary()
+
+# %%
+exper=uni(sample,9, maxlag=3)
+exper.fit()
+exper.print_summary()
+
+# %%
+exper=uni(sample,9, maxlag=6)
+exper.fit()
+exper.print_summary()
+
+# %%
+exper=uni(sample,9, maxlag=9)
+exper.fit()
+exper.print_summary()
+
+# %%
+exper=uni(sample,9, maxlag=12)
+exper.fit()
+exper.print_summary()
+
+# %%
+exper=uni(sample,9, maxlag=0)
+exper.fit()
+exper.print_summary()
+
+# %%
+import numpy as np
+from portfolio_analysis import Bivariate as bi
+    
+    # generate time 
+year = np.ones((3000,1), dtype=int)*2020
+for i in range(19):
+    year = np.append(year, (2019-i)*np.ones((3000,1), dtype=int))
+    
+    # generate character
+character_1 = np.random.normal(0, 1, 20*3000)
+character_2 = np.random.normal(0, 1, 20*3000)
+
+
+
+    # generate future return
+ret=character_1*-0.5 + character_2*0.5 + np.random.normal(0,1,20*3000)
+    # create sample containing future return, character, time
+sample=np.array([ret,character_1, character_2, year]).T
+    # generate the Univiriate Class
+exper=bi(sample,9)
+exper.fit()
+exper.print_summary()
+
+# %%
+exper=bi(sample,9, maxlag=3)
+exper.fit()
+exper.print_summary()
+
+# %%
+exper=bi(sample,9, maxlag=6)
+exper.fit()
+exper.print_summary()
+
+# %%
+exper=bi(sample,9, maxlag=9)
+exper.fit()
+exper.print_summary()
+
+# %%
+exper=bi(sample,9, maxlag=12)
+exper.fit()
+exper.print_summary()
+
+# %%
+exper=bi(sample,9, maxlag=0)
+exper.fit()
+exper.print_summary()
+
 # %%
